@@ -1,5 +1,5 @@
 GetHaplo <-
-function(inputFile=NA,align=NA,saveFile=T,outname="Haplotypes.txt",format="fasta",seqsNames=NA)
+function(inputFile=NA,align=NA,saveFile=TRUE,outname="Haplotypes.txt",format="fasta",seqsNames=NA,silent=FALSE)
 {
 #require(ape)
 if(is.na(inputFile)==TRUE&is.na(align[1])==TRUE) print("Error: Please, define either alignment or input file")
@@ -26,6 +26,7 @@ dimnames(out)[[1]]<-seqsNames
 if(saveFile==T)
 write.dna(out,file=outname,format=format)
 
+if(silent==FALSE)
 print(paste(length(U)," different haplotypes found",ifelse(saveFile==T, {paste(", and saved in the file: \"",outname,"\"",sep="")},{paste(", but not saved in any file",sep="")}),sep=""),quote=F)
 
 
